Module kernels

Module kernels 

Embedded SPIR-V kernel blobs (compiled from kernels/*.cl by build.rs) and their Level Zero module/kernel cache. SPIRV_BLOBS is empty unless the crate was built on an Intel oneAPI host with ocloc + RLX_ONEAPI_BUILD_KERNELS=1, in which case kernels builds one ze_module + ze_kernel per blob (the kernel name equals the .cl function name, which equals the file stem).

Structs

Kernels
Built Level Zero modules + kernels for the embedded SPIR-V blobs.

Constants

KERNELS_BUILT
Whether any native SPIR-V kernel was embedded this build.

Statics

SPIRV_BLOBS
(kernel name, Kernel-flavor SPIR-V byte blob) for every kernels/*.cl compiled by ocloc for this build. Empty when no Intel toolchain.

Functions

blob
SPIR-V byte blob for kernel name, if it was embedded this build.
kernels
Process-wide kernel cache, or None when there is no device or no embedded SPIR-V (the latter is the case on every non-Intel build host).
kernels_built
Whether any native SPIR-V kernel was embedded (false on non-Intel builds).
names
All embedded kernel names (deterministic; build.rs sorts).